############################### Blonkers! ##############################
# File: level.py
#
# Imported by: game.py
#
# Description: Contains Level class
#
#
# (C) Copyright 2011 by Chris Flesner
# This file is released under a GNU All-Permissive License:
# Copying and distribution of this file, with or without modification,
# are permitted in any medium without royalty provided the copyright
# notice and this notice are preserved.  This file is offered as-is,
# without any warranty.
########################################################################

import pygame
from pygame.locals import *
from filenames import *
from sprites import *

class Level:
    def __init__(self):
        self.surface = pygame.Surface(LEVEL_SURFACE_SIZE)
        self.rect = Rect(LEVEL_SURFACE_LEFT, LEVEL_SURFACE_TOP, \
                         self.surface.get_rect().width, \
                         self.surface.get_rect().height)
        self.redrawn_rects = []
        self.background_image = \
                              pygame.image.load(LEVEL_BACKGROUND_FILE).convert()
        #level.surface.fill(pygame.color.Color('black')
        #level.plain_surface.fill(pygame.color.Color('black')

    def fill(self, colorname, rect = None):
        color = pygame.color.Color(colorname)
        if rect == None:
            self.surface.fill(color)
            self.redrawn_rects = [self.surface.get_rect()]
            return

        pygame.draw.rect(self.surface, color, rect)
        self.redrawn_rects.append(rect.copy())

    def blit(self, block):
        self.surface.blit(block.image, block.rect)
        self.redrawn_rects.append(block.rect.copy())

    def update(self, screen):
        for rect in self.redrawn_rects:
            # inflate the rectangle to overcompensate for rounding errors
            # caused by the resizing algorithm in Screen()
            if screen.window_size != screen.start_size:
                redrawn_rect = rect.inflate(10,10)
            else:
                redrawn_rect = rect
            offset_rect = redrawn_rect.copy()
            offset_rect.left += LEVEL_SURFACE_LEFT
            offset_rect.top += LEVEL_SURFACE_TOP
            screen.blit(self.surface, offset_rect, redrawn_rect)
        self.resetRedrawnRects()

    def resetRedrawnRects(self):
        self.redrawn_rects = []

